@@ -46,7 +46,7 @@ class GUI(Tk):
 			AE_path = r'C:\Users\dnt21\AppData\Local\Programs\Python\Python37-32\Lib\site-packages\pyanthem\AE'
 		else:
 			AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
-		if len(os.listdir(AE_path)) < 3073::
+		if len(os.listdir(AE_path)) < 3073:
 			self.AE_run = False
 		else:
 			self.AE_run = True
